# Configuration

DP³ configuration folder consists of these files and folders:

```
db_entities/
modules/
common.yml
database.yml
event_logging.yml
history_manager.yml
processing_core.yml
snapshots.yml
```

Their meaning and usage is explained in following chapters.

## Example configuration

Example configuration is included `config/` folder in [DP³ repository](https://github.com/CESNET/dp3/).
